@@ -124,6 +124,7 @@ class EloquaBulkClient(object):
         fields=None,
         filter=None,
         customObjectId=None,
+        customObjectName=None,
         activityType=None
     ):
         # if fields aren't provided, then fetch all fields of the entity
@@ -133,7 +134,8 @@ class EloquaBulkClient(object):
             elif entity == 'customObjects':
                 fields = self._get_fields_dict(
                     entity=entity,
-                    parentId=customObjectId)
+                    parentId=customObjectId,
+                    parentName=customObjectName)
             elif entity == 'activities':
                 fields = self._get_fields_dict(
                     entity=entity,
@@ -149,8 +151,18 @@ class EloquaBulkClient(object):
             url = '{base_url}/{entity}/exports'.format(
                 base_url=self.bulk_url, entity=entity)
         elif entity == 'customObjects':
+            cdo_id = customObjectId
+            if cdo_id is None and customObjectName is not None:
+                cdo_id = self._get_custom_object_id(
+                    custom_object_name=customObjectName)
+            else:
+                raise TypeError(
+                    '''Either customObjectId or customObjectName
+                    must be provided'''
+                )
+
             url = '{base_url}/{entity}/{parentId}/exports'.format(
-                base_url=self.bulk_url, entity=entity, parentId=customObjectId)
+                base_url=self.bulk_url, entity=entity, parentId=cdo_id)
 
         resp = self.post(url, data)
 
@@ -212,7 +224,13 @@ class EloquaBulkClient(object):
 
         return resp
 
-    def get_fields(self, entity, parentId=None, activityType=None):
+    def get_fields(
+        self,
+        entity,
+        parentId=None,
+        parentName=None,
+        activityType=None
+    ):
         if entity in ('contacts', 'activities'):
             url = '{base_url}/{entity}/fields'.format(
                 base_url=self.bulk_url,
@@ -245,15 +263,63 @@ class EloquaBulkClient(object):
                 fields = resp['items']
 
                 return fields
+            elif parentName is not None:
+                cdo_id = self._get_custom_object_id(
+                    custom_object_name=parentName)
 
+                url = '{base_url}/{entity}/{parentId}/fields'.format(
+                    base_url=self.bulk_url,
+                    entity=entity,
+                    parentId=cdo_id)
+
+                resp = self.get(url)
+                fields = resp['items']
+
+                return fields
             else:
                 raise TypeError(
-                    'You must provide parentId (custom object id)'
+                    '''You must provide parentId (custom object id)
+                    or parentName (custom object name)'''
                 )
 
-    def _get_fields_dict(self, entity, parentId=None, activityType=None):
+    def _get_custom_object_id(self, custom_object_name):
+        if custom_object_name is None:
+            raise TypeError(
+                '''custom_object_name is required'''
+            )
+
+        url = "{base_url}/{entity}?q='name={parentName}'".format(
+            base_url=self.bulk_url,
+            entity='customObjects',
+            parentName=custom_object_name)
+
+        resp = self.get(url)
+        cdos = resp['items']
+
+        if len(cdos) == 0:
+            raise Exception(
+                '''CDO with the name %s not found''' % custom_object_name
+            )
+        elif len(cdos) > 1:
+            raise Exception(
+                '''There are more than one CDO having
+                this name: %s''' % custom_object_name
+            )
+        else:
+            cdo = cdos[0]
+            cdo_id = int(cdo['uri'].split('/')[-1])
+
+            return cdo_id
+
+    def _get_fields_dict(
+        self,
+        entity,
+        parentId=None,
+        parentName=None,
+        activityType=None
+    ):
         fields_dict = {}
-        fields = self.get_fields(entity, parentId, activityType)
+        fields = self.get_fields(entity, parentId, parentName, activityType)
 
         for field in fields:
             fields_dict[field['internalName']] = field['statement']
